Crate endlessgrid

Crate endlessgrid 

Structs

AStarVisit
Struct used by the Grid::astar
Chunk
A Chunk of the Grid
ChunkIndex
Index used internally to identify a chunk within a grid
ChunkIter
ChunkIterMut
Grid
An endless 2D grid of type T implemented using chunks
Index
Index used internally to identify an element within a cell
RayVisit
Struct used by the Grid::cast_ray

Constants

CHUNK_SIZE