Structs
- AStar
Visit - Struct used by the
Grid::astar - Chunk
- A
Chunkof theGrid - Chunk
Index - Index used internally to identify a chunk within a grid
- Chunk
Iter - Chunk
Iter Mut - Grid
- An endless 2D grid of type
Timplemented using chunks - Index
- Index used internally to identify an element within a cell
- RayVisit
- Struct used by the
Grid::cast_ray